/* command-io.h */
#ifndef _GNM_COMMAND_IO_H_
# define _GNM_COMMAND_IO_H_

#include <gnumeric.h>
#include <wbc-gtk.h>
#include <tools/tools.h>
#include <gsf/gsf-libxml.h>
#include <format-template.h>

G_BEGIN_DECLS

void cmdio_start		(WBCGtk *wbcg);
void cmdio_stop			(WBCGtk *wbcg);

void cmdio_write_sheet 		(GsfXMLOut *output, char const *title, Sheet *sheet);
void cmdio_write_position	(GsfXMLOut *output, char const *title, int col, int row);
void cmdio_write_range		(GsfXMLOut *output, char const *title, GnmRange const *r);
void cmdio_write_markup		(GsfXMLOut *output, PangoAttrList const *markup);
void cmdio_write_sheetview	(GsfXMLOut *output, SheetView const *sv);
void cmdio_write_parse_pos	(GsfXMLOut *output, GnmParsePos const *pos);
void cmdio_write_paste_target	(GsfXMLOut *output, GnmPasteTarget const *pt);
void cmdio_write_style		(GsfXMLOut *output, WorkbookControl *wbc, GnmStyle const *style);
void cmdio_write_template_member (GsfXMLOut *output, WorkbookControl *wbc, TemplateMember const *tm);
void cmdio_write_sheet_object_view (GsfXMLOut *output, SheetObjectView const *sov);
void cmdio_write_sheet_object	(GsfXMLOut *output, SheetObject const *so);
void cmdio_write_anchor		(GsfXMLOut *output, SheetObjectAnchor const *anchor);

void cmdio_write_set_text	(WorkbookControl *wbc, Sheet *sheet,
				 GnmCellPos const *pos, char const *new_text,
				 PangoAttrList *markup);

void cmdio_write_area_set_text	(WorkbookControl *wbc, SheetView *sv,
				 char const *text, gboolean as_array);

void cmdio_write_create_data_table	(WorkbookControl *wbc,
					 Sheet *sheet, GnmRange const *r,
					 char const *col_input, char const *row_input);

void cmdio_write_ins_del_colrow		(WorkbookControl *wbc, Sheet *sheet,
					 gboolean is_cols, gboolean is_insert,
					 int index, int count);

void cmdio_write_resize_colrow	(WorkbookControl *wbc, Sheet *sheet,
				 gboolean is_cols, ColRowIndexList *selection,
				 int new_size);

void cmdio_write_paste_cut	(WorkbookControl *wbc,
				 GnmExprRelocateInfo const *info,
				 gboolean move_selection,
				 char *cmd_descriptor);

void cmdio_write_paste_copy	(WorkbookControl *wbc,
				 GnmPasteTarget const *pt, GnmCellRegion const *cr);

void cmdio_write_sort		(WorkbookControl *wbc, GnmSortData const *data);

void cmdio_write_autofill	(WorkbookControl *wbc, Sheet *sheet,
				 gboolean default_increment,
				 int base_col, int base_row,
				 int w, int h, int end_col, int end_row,
				 gboolean inverse_autofill);

void cmdio_write_copyrel	(WorkbookControl *wbc,
				 int dx, int dy,
				 char const *name);

/* From commands.h: the following work on the current sheet and the
 * calling control's selection (need to store this info...)
 */
void cmdio_write_selection_format	(WorkbookControl *wbc,
					 GnmStyle *style, GnmBorder **borders,
					 char const *opt_translated_name);

void cmdio_write_selection_clear	(WorkbookControl *wbc, int clear_flags);

void cmdio_write_selection_colrow_hide	(WorkbookControl *wbc,
					 gboolean is_cols, gboolean visible);

void cmdio_write_selection_outline_change	(WorkbookControl *wbc,
						 gboolean is_cols, int index, int depth);

void cmdio_write_selection_group	(WorkbookControl *wbc,
					 gboolean is_cols, gboolean group);

void cmdio_write_selection_autoformat	(WorkbookControl *wbc,
					 GnmFormatTemplate *ft);

void cmdio_write_global_outline_change	(WorkbookControl *wbc,
					 gboolean is_cols, int depth);

void cmdio_write_merge_cells		(WorkbookControl *wbc, Sheet *sheet,
					 GSList const *selection, gboolean center);

void cmdio_write_unmerge_cells		(WorkbookControl *wbc, Sheet *sheet,
					 GSList const *selection);

void cmdio_write_search_replace		(WorkbookControl *wbc, GnmSearchReplace *sr);

void cmdio_write_colrow_std_size	(WorkbookControl *wbc, Sheet *sheet,
					 gboolean is_cols, double new_default);

void cmdio_write_zoom		(WorkbookControl *wbc, GSList *sheets,
				 double factor);

void cmdio_write_objects_delete	(WorkbookControl *wbc, GSList *objects,
				 char const *name);

void cmdio_write_objects_move	(WorkbookControl *wbc,
				 GSList *objects, GSList *anchors,
				 gboolean objects_created, char const *name);

void cmdio_write_object_format	(WorkbookControl *wbc, SheetObject *so,
				 gpointer orig_style);

void cmdio_write_reorganize_sheets	(WorkbookControl *wbc,
					 WorkbookSheetState *old_state,
					 Sheet *undo_sheet);

void cmdio_write_rename_sheet		(WorkbookControl *wbc, Sheet *sheet,
					 char const *new_name);

G_END_DECLS

#endif /* _GNM_COMMAND_IO_H_ */
